pub fn convert(
model_id: &str,
files: &ModelFiles,
config: &TotoConfig,
opts: &ConvertOptions,
output_path: &Path,
) -> Result<()>Expand description
Read files, convert every tensor, and write a GGUF file to output_path.
pub fn convert(
model_id: &str,
files: &ModelFiles,
config: &TotoConfig,
opts: &ConvertOptions,
output_path: &Path,
) -> Result<()>Read files, convert every tensor, and write a GGUF file to output_path.