pub struct ConvertOptions {
pub output_dtype: GGMLType,
}Expand description
Options that control how tensors are stored in the output GGUF.
Fields
output_dtype: GGMLTypeTarget dtype for all tensors in the output file.